@@ -540,13 +540,14 @@ refresh_changes(GitgCommit *commit, GitgChangedFile *file)
 	update_index_unstaged(commit, file);
 	
 	GitgChangedFileChanges changes = gitg_changed_file_get_changes(file);
-	
-	if (changes == GITG_CHANGED_FILE_CHANGES_NONE)
+	GitgChangedFileStatus status = gitg_changed_file_get_status(file);
+
+	if (changes == GITG_CHANGED_FILE_CHANGES_NONE && status == GITG_CHANGED_FILE_CHANGES_NONE)
 		gitg_changed_file_set_status(file, GITG_CHANGED_FILE_STATUS_NEW);
 	else if ((changes & GITG_CHANGED_FILE_CHANGES_CACHED) && (changes & GITG_CHANGED_FILE_CHANGES_UNSTAGED))
 		gitg_changed_file_set_status(file, GITG_CHANGED_FILE_STATUS_MODIFIED);
 	
-	if (gitg_changed_file_get_status(file) == GITG_CHANGED_FILE_STATUS_NEW &&
+	if (status == GITG_CHANGED_FILE_STATUS_NEW &&
 	    !(changes & GITG_CHANGED_FILE_CHANGES_CACHED))
 	{
 		gitg_changed_file_set_changes(file, GITG_CHANGED_FILE_CHANGES_UNSTAGED);
@@ -870,3 +871,21 @@ on_changed_file_changed(GitgChangedFile *file, GitgCommit *commit)
 {
 	refresh_changes(commit, file);
 }
+
+GitgChangedFile *
+gitg_commit_find_changed_file(GitgCommit *commit, GFile *file)
+{
+	g_return_val_if_fail(GITG_IS_COMMIT(commit), NULL);
+	g_return_val_if_fail(G_IS_FILE(file), NULL);
+	
+	GitgChangedFile *f = g_hash_table_lookup(commit->priv->files, file);
+	
+	if (f != NULL)
+	{
+		return g_object_ref(f);
+	}
+	else
+	{
+		return NULL;
+	}
+}
